<!--

Important: Before opening a PR, make sure to read https://github.com/xsuite/xplt/wiki/Contributing

-->


## Description
<!-- Describe why you are making the changes you do
 including code snippets and/or screenshots where applicable
 and link the relevant issues below. -->

```python
```

Closes #



## Checklist

Mandatory: 
- [ ] I described my changes in this PR description
- [ ] I have added/updated the docs (docstrings) in relation to my changes
- [ ] The code I wrote follows good style practices (see [PEP 8](https://peps.python.org/pep-0008/) and [PEP 20](https://peps.python.org/pep-0020/))

Optional:
- [ ] I have added/updated examples to show the usage of new features introduced (only for major changes)
- [ ] I have added tests to cover my changes
- [ ] All the tests are passing, including my new ones
